summaryrefslogtreecommitdiffstats
path: root/kviewshell/documentRenderer.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 06:08:18 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 06:08:18 +0000
commitda4be7880ff1de6415ab6256afd2514e64f5fa2e (patch)
tree0862c14883af0435b012f6f592221fc167ed7d91 /kviewshell/documentRenderer.h
parentd0a269b9b0361bf71c5dd5787be0839f9dcace8c (diff)
downloadtdegraphics-da4be7880ff1de6415ab6256afd2514e64f5fa2e.tar.gz
tdegraphics-da4be7880ff1de6415ab6256afd2514e64f5fa2e.zip
rename the following methods:
tqfind find tqreplace replace tqcontains contains git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdegraphics@1246075 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kviewshell/documentRenderer.h')
-rw-r--r--kviewshell/documentRenderer.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/kviewshell/documentRenderer.h b/kviewshell/documentRenderer.h
index a49b1ba7..69ec87cb 100644
--- a/kviewshell/documentRenderer.h
+++ b/kviewshell/documentRenderer.h
@@ -152,7 +152,7 @@ public:
virtual void clear();
/* Returns true if the current document tqcontains 0 pages. */
bool isEmpty() const {return numPages == 0;}
/* Tells if the document was modified after is was loaded. */
@@ -262,7 +262,7 @@ public:
display device. In principle. In fact, kviewshell implements zooming
by using values that are not exactly the resolution of the display,
but multiplied with the zoom factor. Bottom line: the
- DocumentRenderer should act as if this field indeed tqcontains
+ DocumentRenderer should act as if this field indeed contains
resolution of the display device.
@param page pointer to a documentPage structure that this method
@@ -152,7 +152,7 @@ public:
virtual void clear();
- /* Returns true if the current document tqcontains 0 pages. */
+ /* Returns true if the current document contains 0 pages. */
bool isEmpty() const {return numPages == 0;}
/* Tells if the document was modified after is was loaded. */